pub struct DatabentoImbalance {
pub instrument_id: InstrumentId,
pub ref_price: Price,
pub cont_book_clr_price: Price,
pub auct_interest_clr_price: Price,
pub paired_qty: Quantity,
pub total_imbalance_qty: Quantity,
pub side: OrderSide,
pub significant_imbalance: c_char,
pub ts_event: UnixNanos,
pub ts_recv: UnixNanos,
pub ts_init: UnixNanos,
}Expand description
Represents an auction imbalance.
This data type includes the populated data fields provided by Databento,
excluding publisher_id and instrument_id.
Fields
instrument_id: InstrumentIdref_price: Pricecont_book_clr_price: Priceauct_interest_clr_price: Pricepaired_qty: Quantitytotal_imbalance_qty: Quantityside: OrderSidesignificant_imbalance: c_charts_event: UnixNanosts_recv: UnixNanosts_init: UnixNanosImplementations
Sourceimpl DatabentoImbalance
impl DatabentoImbalance
Sourcepub fn get_metadata(
instrument_id: &InstrumentId,
price_precision: u8,
size_precision: u8,
) -> HashMap<String, String>
pub fn get_metadata( instrument_id: &InstrumentId, price_precision: u8, size_precision: u8, ) -> HashMap<String, String>
Returns the metadata for the type, for use with serialization formats.
Sourcepub const fn new(
instrument_id: InstrumentId,
ref_price: Price,
cont_book_clr_price: Price,
auct_interest_clr_price: Price,
paired_qty: Quantity,
total_imbalance_qty: Quantity,
side: OrderSide,
significant_imbalance: c_char,
ts_event: UnixNanos,
ts_recv: UnixNanos,
ts_init: UnixNanos,
) -> Self
pub const fn new( instrument_id: InstrumentId, ref_price: Price, cont_book_clr_price: Price, auct_interest_clr_price: Price, paired_qty: Quantity, total_imbalance_qty: Quantity, side: OrderSide, significant_imbalance: c_char, ts_event: UnixNanos, ts_recv: UnixNanos, ts_init: UnixNanos, ) -> Self
Creates a new DatabentoImbalance instance.
Sourceimpl DatabentoImbalance
impl DatabentoImbalance
Sourcepub fn py_to_dict(&self, py: Python<'_>) -> PyResult<Py<PyAny>>
pub fn py_to_dict(&self, py: Python<'_>) -> PyResult<Py<PyAny>>
Errors
Returns a PyErr if generating the Python dictionary fails.