pub struct DatabentoStatistics {Show 13 fields
pub instrument_id: InstrumentId,
pub stat_type: DatabentoStatisticType,
pub update_action: DatabentoStatisticUpdateAction,
pub price: Option<Price>,
pub quantity: Option<Quantity>,
pub channel_id: u16,
pub stat_flags: u8,
pub sequence: u32,
pub ts_ref: UnixNanos,
pub ts_in_delta: i32,
pub ts_event: UnixNanos,
pub ts_recv: UnixNanos,
pub ts_init: UnixNanos,
}Expand description
Represents a market statistics snapshot.
This data type includes the populated data fields provided by Databento,
excluding publisher_id and instrument_id.
Fields
instrument_id: InstrumentIdstat_type: DatabentoStatisticTypeupdate_action: DatabentoStatisticUpdateActionprice: Option<Price>quantity: Option<Quantity>channel_id: u16stat_flags: u8sequence: u32ts_ref: UnixNanosts_in_delta: i32ts_event: UnixNanosts_recv: UnixNanosts_init: UnixNanosImplementations
Sourceimpl DatabentoStatistics
impl DatabentoStatistics
Sourcepub fn get_metadata(
instrument_id: &InstrumentId,
price_precision: u8,
size_precision: u8,
) -> HashMap<String, String>
pub fn get_metadata( instrument_id: &InstrumentId, price_precision: u8, size_precision: u8, ) -> HashMap<String, String>
Returns the metadata for the type, for use with serialization formats.
Sourcepub const fn new(
instrument_id: InstrumentId,
stat_type: DatabentoStatisticType,
update_action: DatabentoStatisticUpdateAction,
price: Option<Price>,
quantity: Option<Quantity>,
channel_id: u16,
stat_flags: u8,
sequence: u32,
ts_ref: UnixNanos,
ts_in_delta: i32,
ts_event: UnixNanos,
ts_recv: UnixNanos,
ts_init: UnixNanos,
) -> Self
pub const fn new( instrument_id: InstrumentId, stat_type: DatabentoStatisticType, update_action: DatabentoStatisticUpdateAction, price: Option<Price>, quantity: Option<Quantity>, channel_id: u16, stat_flags: u8, sequence: u32, ts_ref: UnixNanos, ts_in_delta: i32, ts_event: UnixNanos, ts_recv: UnixNanos, ts_init: UnixNanos, ) -> Self
Creates a new DatabentoStatistics instance.
Sourceimpl DatabentoStatistics
impl DatabentoStatistics
Sourcepub fn py_to_dict(&self, py: Python<'_>) -> PyResult<Py<PyAny>>
pub fn py_to_dict(&self, py: Python<'_>) -> PyResult<Py<PyAny>>
Errors
Returns a PyErr if generating the Python dictionary fails.